"use strict";

require("core-js/modules/es6.object.define-property");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

require("core-js/modules/es6.object.assign");

require("core-js/modules/es6.array.find");

require("core-js/modules/es6.array.for-each");

require("core-js/modules/es6.function.name");

require("core-js/modules/es7.object.values");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es6.object.keys");

var _lodash = _interopRequireDefault(require("lodash.pick"));

var _utilDeprecate = _interopRequireDefault(require("util-deprecate"));

var _fastDeepEqual = _interopRequireDefault(require("fast-deep-equal"));

var _theming = require("@storybook/theming");

var _merge = _interopRequireDefault(require("../libs/merge"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var deprecatedThemeOptions = {
  name: 'brandTitle',
  url: 'brandUrl'
};
var deprecatedLayoutOptions = {
  goFullScreen: 'isFullscreen',
  showStoriesPanel: 'showNav',
  showAddonPanel: 'showPanel',
  addonPanelInRight: 'panelPosition'
};

var deprecationMessage = function deprecationMessage(optionsMap, prefix) {
  return "The options { ".concat(Object.keys(optionsMap).join(', '), " } are deprecated -- use ").concat(prefix ? "".concat(prefix, "'s") : '', " { ").concat(Object.values(optionsMap).join(', '), " } instead.");
};

var applyDeprecatedThemeOptions = (0, _utilDeprecate.default)(function (_ref) {
  var name = _ref.name,
      url = _ref.url;
  return {
    brandTitle: name,
    brandUrl: url,
    brandImage: null
  };
}, deprecationMessage(deprecatedThemeOptions));
var applyDeprecatedLayoutOptions = (0, _utilDeprecate.default)(function (options) {
  var layoutUpdate = {};
  ['goFullScreen', 'showStoriesPanel', 'showAddonPanel'].forEach(function (option) {
    if (typeof options[option] !== 'undefined') {
      layoutUpdate[deprecatedLayoutOptions[option]] = options[option];
    }
  });

  if (options.addonPanelInRight) {
    layoutUpdate.panelPosition = 'right';
  }

  return layoutUpdate;
}, deprecationMessage(deprecatedLayoutOptions));

var checkDeprecatedThemeOptions = function checkDeprecatedThemeOptions(options) {
  if (Object.keys(deprecatedThemeOptions).find(function (key) {
    return !!options[key];
  })) {
    return applyDeprecatedThemeOptions(options);
  }

  return {};
};

var checkDeprecatedLayoutOptions = function checkDeprecatedLayoutOptions(options) {
  if (Object.keys(deprecatedLayoutOptions).find(function (key) {
    return typeof options[key] !== 'undefined';
  })) {
    return applyDeprecatedLayoutOptions(options);
  }

  return {};
};

var initial = {
  ui: {
    enableShortcuts: true,
    sortStoriesByKind: false,
    sidebarAnimations: true
  },
  layout: {
    isToolshown: true,
    isFullscreen: false,
    showPanel: true,
    showNav: true,
    panelPosition: 'bottom'
  },
  theme: _theming.themes.light
};
var hasSetOptions = false;

function _default(_ref2) {
  var store = _ref2.store;
  var api = {
    toggleFullscreen: function toggleFullscreen(toggled) {
      return store.setState(function (state) {
        var value = typeof toggled !== 'undefined' ? toggled : !state.layout.isFullscreen;
        return {
          layout: Object.assign({}, state.layout, {
            isFullscreen: value
          })
        };
      });
    },
    togglePanel: function togglePanel(toggled) {
      return store.setState(function (state) {
        var value = typeof toggled !== 'undefined' ? toggled : !state.layout.showPanel;
        return {
          layout: Object.assign({}, state.layout, {
            showPanel: value
          })
        };
      });
    },
    togglePanelPosition: function togglePanelPosition(position) {
      if (typeof position !== 'undefined') {
        return store.setState(function (state) {
          return {
            layout: Object.assign({}, state.layout, {
              panelPosition: position
            })
          };
        });
      }

      return store.setState(function (state) {
        return {
          layout: Object.assign({}, state.layout, {
            panelPosition: state.layout.panelPosition === 'right' ? 'bottom' : 'right'
          })
        };
      });
    },
    toggleNav: function toggleNav(toggled) {
      return store.setState(function (state) {
        var value = typeof toggled !== 'undefined' ? toggled : !state.layout.showNav;
        return {
          layout: Object.assign({}, state.layout, {
            showNav: value
          })
        };
      });
    },
    toggleToolbar: function toggleToolbar(toggled) {
      return store.setState(function (state) {
        var value = typeof toggled !== 'undefined' ? toggled : !state.layout.isToolshown;
        return {
          layout: Object.assign({}, state.layout, {
            isToolshown: value
          })
        };
      });
    },
    setOptions: function setOptions(options) {
      // The very first time the user sets their options, we don't consider what is in the store.
      // At this point in time, what is in the store is what we *persisted*. We did that in order
      // to avoid a FOUC (e.g. initial rendering the wrong theme while we waited for the stories to load)
      // However, we don't want to have a memory about these things, otherwise we see bugs like the
      // user setting a name for their storybook, persisting it, then never being able to unset it
      // without clearing localstorage. See https://github.com/storybooks/storybook/issues/5857
      var _ref3 = hasSetOptions ? store.getState() : initial,
          layout = _ref3.layout,
          ui = _ref3.ui,
          selectedPanel = _ref3.selectedPanel,
          theme = _ref3.theme;

      if (options) {
        var updatedLayout = Object.assign({}, layout, (0, _lodash.default)(options, Object.keys(layout)), checkDeprecatedLayoutOptions(options));
        var updatedUi = Object.assign({}, ui, (0, _lodash.default)(options, Object.keys(ui)));
        var updatedTheme = Object.assign({}, theme, options.theme, checkDeprecatedThemeOptions(options));
        var modification = {};

        if (!(0, _fastDeepEqual.default)(ui, updatedUi)) {
          modification.ui = updatedUi;
        }

        if (!(0, _fastDeepEqual.default)(layout, updatedLayout)) {
          modification.layout = updatedLayout;
        }

        if (!(0, _fastDeepEqual.default)(theme, updatedTheme)) {
          modification.theme = updatedTheme;
        }

        if (!(0, _fastDeepEqual.default)(selectedPanel, options.selectedPanel)) {
          modification.selectedPanel = options.selectedPanel;
        }

        if (Object.keys(modification).length) {
          store.setState(modification, {
            persistence: 'permanent'
          });
        }

        hasSetOptions = true;
      }
    }
  };
  var persisted = (0, _lodash.default)(store.getState(), 'layout', 'ui', 'selectedPanel', 'theme');
  var state = (0, _merge.default)(initial, persisted);
  return {
    api: api,
    state: state
  };
}